@@ -23,7 +23,7 @@ func NewRbac(gvr client.GVR) ResourceViewer {
 		ResourceViewer: NewBrowser(gvr),
 	}
 	r.AddBindKeysFn(r.bindKeys)
-	r.GetTable().SetSortCol("APIGROUP", true)
+	r.GetTable().SetSortCol("API-GROUP", true)
 	r.GetTable().SetEnterFn(blankEnterFn)
 
 	return &r
@@ -32,11 +32,11 @@ func NewRbac(gvr client.GVR) ResourceViewer {
 func (r *Rbac) bindKeys(aa ui.KeyActions) {
 	aa.Delete(ui.KeyShiftA, tcell.KeyCtrlSpace, ui.KeySpace)
 	aa.Add(ui.KeyActions{
-		ui.KeyShiftO: ui.NewKeyAction("Sort APIGroup", r.GetTable().SortColCmd("APIGROUP", true), false),
+		ui.KeyShiftA: ui.NewKeyAction("Sort API-Group", r.GetTable().SortColCmd("API-GROUP", true), false),
 	})
 }
 
-func showRules(app *App, _ ui.Tabular, gvr, path string) {
+func showRules(app *App, _ ui.Tabular, gvr client.GVR, path string) {
 	v := NewRbac(client.NewGVR("rbac"))
 	v.SetContextFn(rbacCtx(gvr, path))
 
@@ -45,11 +45,11 @@ func showRules(app *App, _ ui.Tabular, gvr, path string) {
 	}
 }
 
-func rbacCtx(gvr, path string) ContextFunc {
+func rbacCtx(gvr client.GVR, path string) ContextFunc {
 	return func(ctx context.Context) context.Context {
 		ctx = context.WithValue(ctx, internal.KeyPath, path)
 		return context.WithValue(ctx, internal.KeyGVR, gvr)
 	}
 }
 
-func blankEnterFn(_ *App, _ ui.Tabular, _, _ string) {}
+func blankEnterFn(_ *App, _ ui.Tabular, _ client.GVR, _ string) {}
